pub struct GameRecordsBuilder<'a> { /* private fields */ }Expand description
Builder for GameRecords.
Implementations
Sourceimpl<'a> GameRecordsBuilder<'a>
impl<'a> GameRecordsBuilder<'a>
Sourcepub fn id<VALUE: Into<GameId<'a>>>(&mut self, value: VALUE) -> &mut Self
pub fn id<VALUE: Into<GameId<'a>>>(&mut self, value: VALUE) -> &mut Self
ID of the game to retrieve records for.
Sourcepub fn top<VALUE: Into<i64>>(&mut self, value: VALUE) -> &mut Self
pub fn top<VALUE: Into<i64>>(&mut self, value: VALUE) -> &mut Self
Return the top places (this can result in more than top runs!). Defaults to 3.
Sourcepub fn scope<VALUE: Into<LeaderboardScope>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn scope<VALUE: Into<LeaderboardScope>>( &mut self, value: VALUE, ) -> &mut Self
When set to LeaderboardScope::FullGame, only full-game categories will be included. When set to LeaderboardScope::Levels only individual levels are returned. Defaults to LeaderboardScope::All.
Sourcepub fn miscellaneous<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn miscellaneous<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
When false, miscellaneous categories will not be included in the results.
Sourcepub fn skip_empty<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn skip_empty<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
When true, empty leaderboards will not be included in the results.
Sourcepub fn build(&self) -> Result<GameRecords<'a>, GameRecordsBuilderError>
pub fn build(&self) -> Result<GameRecords<'a>, GameRecordsBuilderError>
Sourceimpl GameRecordsBuilder<'_>
impl GameRecordsBuilder<'_>
Sourcepub fn embed(&mut self, embed: LeaderboardEmbeds) -> &mut Self
pub fn embed(&mut self, embed: LeaderboardEmbeds) -> &mut Self
Add an embedded resource to this result.
Sourcepub fn embeds<I>(&mut self, iter: I) -> &mut Selfwhere
I: Iterator<Item = LeaderboardEmbeds>,
pub fn embeds<I>(&mut self, iter: I) -> &mut Selfwhere
I: Iterator<Item = LeaderboardEmbeds>,
Add multiple embedded resources to this result.