pub struct FullGameLeaderboardBuilder<'a> { /* private fields */ }Expand description
Builder for FullGameLeaderboard.
Implementations
Sourceimpl<'a> FullGameLeaderboardBuilder<'a>
impl<'a> FullGameLeaderboardBuilder<'a>
Sourcepub fn game<VALUE: Into<GameId<'a>>>(&mut self, value: VALUE) -> &mut Self
pub fn game<VALUE: Into<GameId<'a>>>(&mut self, value: VALUE) -> &mut Self
Game ID or abbreviation.
Sourcepub fn category<VALUE: Into<CategoryId<'a>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn category<VALUE: Into<CategoryId<'a>>>( &mut self, value: VALUE, ) -> &mut Self
Category ID or abbreviation.
Sourcepub fn platform<VALUE: Into<PlatformId<'a>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn platform<VALUE: Into<PlatformId<'a>>>( &mut self, value: VALUE, ) -> &mut Self
Only return runs done on platform.
Sourcepub fn region<VALUE: Into<RegionId<'a>>>(&mut self, value: VALUE) -> &mut Self
pub fn region<VALUE: Into<RegionId<'a>>>(&mut self, value: VALUE) -> &mut Self
Only return runs done in region.
Sourcepub fn emulators<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn emulators<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
When unset, real devices and emulator results are returned. When true only emulator runs are returned, otherwise only real deivces are returned.
Sourcepub fn video_only<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn video_only<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
When true only runs with videos will be returned. (default: false)
Sourcepub fn timing<VALUE: Into<TimingMethod>>(&mut self, value: VALUE) -> &mut Self
pub fn timing<VALUE: Into<TimingMethod>>(&mut self, value: VALUE) -> &mut Self
What TimingMethod to use to determine the sorting of runs.
Sourcepub fn date<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn date<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Only return runs done on or before this date. ISO 8601 date string.
Sourcepub fn build(
&self,
) -> Result<FullGameLeaderboard<'a>, FullGameLeaderboardBuilderError>
pub fn build( &self, ) -> Result<FullGameLeaderboard<'a>, FullGameLeaderboardBuilderError>
Sourceimpl<'a> FullGameLeaderboardBuilder<'a>
impl<'a> FullGameLeaderboardBuilder<'a>
Sourcepub fn embed(&mut self, embed: LeaderboardEmbeds) -> &mut Self
pub fn embed(&mut self, embed: LeaderboardEmbeds) -> &mut Self
Add an embedded resource to this result
Sourcepub fn embeds<I>(&mut self, iter: I) -> &mut Selfwhere
I: Iterator<Item = LeaderboardEmbeds>,
pub fn embeds<I>(&mut self, iter: I) -> &mut Selfwhere
I: Iterator<Item = LeaderboardEmbeds>,
Add multiple embedded resources to this result
Sourcepub fn variable<Var, Val>(&mut self, variable: Var, value: Val) -> &mut Self
pub fn variable<Var, Val>(&mut self, variable: Var, value: Val) -> &mut Self
Add a single custom variable to filter results by.